@@ -167,6 +167,18 @@ impl Image {
             }
         })
     }
+
+    /// Provides an alternate method for parsing that associates the URL
+    /// with anonymous CORS headers.
+    pub fn parse_with_cors_anonymous<'i, 't>(
+        context: &ParserContext,
+        input: &mut Parser<'i, 't>,
+    ) -> Result<Image, ParseError<'i>> {
+        if let Ok(url) = input.try(|input| SpecifiedImageUrl::parse_with_cors_anonymous(context, input)) {
+            return Ok(GenericImage::Url(url));
+        }
+        Self::parse(context, input)
+    }
 }
 
 impl Parse for Gradient {
